@@ -37,7 +37,9 @@
 
 #include <glib-object.h>
 
+#ifndef GNOME_DISABLE_DEPRECATED
 #include <popt.h>
+#endif
 
 G_BEGIN_DECLS
 
@@ -164,7 +166,7 @@ struct _GnomeModuleInfo {
     GnomeModuleHook pre_args_parse, post_args_parse;
 
 #ifdef GNOME_DISABLE_DEPRECATED
-    struct poptOption *_options;
+    void *_options;
 #else
     struct poptOption *options;
 #endif
@@ -195,6 +197,8 @@ gnome_program_install_property (GnomeProgramClass *pclass,
 				GObjectSetPropertyFunc set_fn,
 				GParamSpec *pspec);
 
+#ifndef GNOME_DISABLE_DEPRECATED
+
 /*
  * If the application writer wishes to use getopt()-style arg
  * processing, they can do it using a while looped sandwiched between
@@ -212,6 +216,8 @@ gnome_program_parse_args (GnomeProgram *program);
 void
 gnome_program_postinit (GnomeProgram *program);
 
+#endif /* GNOME_DISABLE_DEPRECATED */
+
 /* If you have your auto* define PREFIX, SYSCONFDIR, DATADIR and LIBDIR,
  * Use this macro in your init code. */
 #define GNOME_PROGRAM_STANDARD_PROPERTIES \
@@ -220,8 +226,6 @@ gnome_program_postinit (GnomeProgram *program);
 	GNOME_PARAM_APP_DATADIR, DATADIR,	\
 	GNOME_PARAM_APP_LIBDIR, LIBDIR
 
-/* These are convenience functions that calls gnomelib_preinit(...), have
-   popt parse all args, and then call gnomelib_postinit() */
 GnomeProgram *
 gnome_program_init (const char *app_id, const char *app_version,
 		    const GnomeModuleInfo *module_info,
